@@ -7,7 +7,7 @@ from pyxk.m3u8._parser import M3U8
 @click.argument("uri", metavar="m3u8链接地址", type=str)
 @click.option("-o", "--output", help="下载保存文件名称", default=None, type=str)
 @click.option("-r", "--rerequest/--no-rerequest", help="重新请求m3u8资源", default=False)
-@click.option("--delete/--no-delete", help="下载完成后, 删除m3u8本地资源", default=False)
+@click.option("--delete/--no-delete", help="下载完成后, 删除m3u8本地资源", default=True)
 @click.option("--reserve/--no-reserve", help="下载完成后, 保留segments", default=False)
 @click.option("--headers", help="request请求头", default=None, type=str)
 @click.option("--verify/--no-verify", help="request SSL验证", default=True)
